local coveredBridge = ...

-- Apply building asset processor
coveredBridge:registerAssetProcessor("models/coveredBridge.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
coveredBridge:registerAssetProcessor("models/coveredBridgeDecoration.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
coveredBridge:registerAssetProcessor("models/coveredBridgeGate.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
coveredBridge:registerAssetProcessor("models/coveredBridgeAddition.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

local myMonument = {
	Id = "COVERED_BRIDGE_V3",
	Name = "COVERED_BRIDGE_V3_MONUMENT_NAME",
	Description = "COVERED_BRIDGE_V3_MONUMENT_DESC",
	BuildingType = "MONUMENT",
	IsManuallyUnlocked = false,
	IsDestructible = true,
	IsEditable = true,
	IsClearTrees = true
}

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    coveredBridge:log("Hello World: version 1.5")
    myMonument.DataType = "MONUMENT"
    myMonument.BuildingPartSetList = {
		{
			Name = "COVERED_BRIDGE_V3_NAME",
	                BuildingPartList = {
		            "COVERED_BRIDGE_V3_CORE_PART",
		            "COVERED_BRIDGE_V3_HOUSE_PART",
                            "COVERED_BRIDGE_V3_RED_PART",
                            "COVERED_BRIDGE_V3_GREEN_A_PART",
		            "COVERED_BRIDGE_V3_GREEN_B_PART",
                            "COVERED_BRIDGE_V3_BLUE_PART",
		            "COVERED_BRIDGE_V3_RED_WINE_PART",
		            "COVERED_BRIDGE_V3_CARBON_PART",
		            "COVERED_BRIDGE_V3_CENTER_COVERAGE_PART",
		            "COVERED_BRIDGE_V3_START_END_COVERAGE_PART",
		            "COVERED_BRIDGE_V3_GATE_ROOT_PART"
	                }
                }
    }
    _MoverStart = "BUILDING_PART_MOVER"
    _MoverCore = "BUILDING_PART_MOVER_BRIDGE"
    _ConstructorDataStart = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "COVERED_BRIDGE_V3_START_PREFAB",
		FillerList = {
			"COVERED_BRIDGE_V3_TILING_PART"
		},
		BasementScale = 2
    }
    _ConstructorDataEnd =  {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "COVERED_BRIDGE_V3_END_PREFAB",
		FillerList = {
			"COVERED_BRIDGE_V3_TILING_PART"
		},
		BasementScale = 2
    }
else
    coveredBridge:log("Hello World: version 1.6")
    myMonument.DataType = "BUILDING"
    myMonument.AssetCoreBuildingPart = "COVERED_BRIDGE_V3_CORE_PART"
    myMonument.BuildingPartSetList = {
		{
			Name = "COVERED_BRIDGE_V3_NAME",
	                BuildingPartList = {
		            "COVERED_BRIDGE_V3_HOUSE_PART",
                            "COVERED_BRIDGE_V3_RED_PART",
                            "COVERED_BRIDGE_V3_GREEN_A_PART",
		            "COVERED_BRIDGE_V3_GREEN_B_PART",
                            "COVERED_BRIDGE_V3_BLUE_PART",
		            "COVERED_BRIDGE_V3_RED_WINE_PART",
		            "COVERED_BRIDGE_V3_CARBON_PART",
		            "COVERED_BRIDGE_V3_CENTER_COVERAGE_PART",
		            "COVERED_BRIDGE_V3_START_END_COVERAGE_PART",
		            "COVERED_BRIDGE_V3_GATE_ROOT_PART"
	                }
                }
    }
    _MoverStart = "BUILDING_PART_MOVER_BRIDGE"
    _MoverCore = "BUILDING_PART_MOVER"
    _ConstructorDataStart =  {
		DataType = "BUILDING_CONSTRUCTOR_SLOPE",
		CoreObjectPrefab = "COVERED_BRIDGE_V3_START_PREFAB",
		SlopePartList = {
			"COVERED_BRIDGE_V3_SLOPE_START_PART"
		},
		CoreBasementPartList = {
			"COVERED_BRIDGE_V3_TILING_PART"
		},
		UpperAttachType = ATTACH_NODE_TYPE.RIGHT,
		LowerAttachType = ATTACH_NODE_TYPE.LEFT
    }
    _ConstructorDataEnd = {
		DataType = "BUILDING_CONSTRUCTOR_SLOPE",
		CoreObjectPrefab = "COVERED_BRIDGE_V3_END_PREFAB",
		SlopePartList = {
			"COVERED_BRIDGE_V3_SLOPE_END_PART"
		},
		CoreBasementPartList = {
			"COVERED_BRIDGE_V3_TILING_PART"
		},
		UpperAttachType = ATTACH_NODE_TYPE.LEFT,
		LowerAttachType = ATTACH_NODE_TYPE.RIGHT,
    } 
end

-- Register all covered bridge building parts and their properties
coveredBridge:dofile("scripts/building_parts.lua")

-- Register the covered bridge monument
coveredBridge:register(myMonument)